aboutsummaryrefslogtreecommitdiff
path: root/sh/profile.d/browser.sh
diff options
context:
space:
mode:
Diffstat (limited to 'sh/profile.d/browser.sh')
-rw-r--r--sh/profile.d/browser.sh12
1 files changed, 9 insertions, 3 deletions
diff --git a/sh/profile.d/browser.sh b/sh/profile.d/browser.sh
index ee94857c..ce18e127 100644
--- a/sh/profile.d/browser.sh
+++ b/sh/profile.d/browser.sh
@@ -1,4 +1,10 @@
-# Set command-line browser to lynx; ~/.xsession will change this to something
-# graphical instead if invoked
-BROWSER=lynx
+# Set command-line browser to Debian's alternatives name www-browser, or
+# failing that, just to `lynx`; ~/.xsession will change this to something
+# graphical instead if invoked.
+#
+if command -v www-browser >/dev/null 2>&1 ; then
+ BROWSER=www-browser
+else
+ BROWSER=lynx
+fi
export BROWSER